# EuroCropsML
*Ready-to-use benchmark dataset for few-shot crop type classification using Sentinel-2 imagery.*

Release **v{sub-ref}`release`**

```{include} ../README.md
:start-after: 'teaser-begin -->'
:end-before: '<!-- teaser-end'
:relative-docs: docs/
:relative-images:
```

---

## Table of Contents

```{toctree}
:maxdepth: 2

🔎 Overview <self>
🚀 Getting Started <starting>
💡 Examples <examples>
```

```{toctree}
:caption: 📖 References
:maxdepth: 2

Dataset Reference <dataset>
CLI Reference <cli>
API Reference <api>
```

```{toctree}
:caption: 🚩 Project Links
:maxdepth: 1

license
PyPI <https://pypi.org/project/eurocropsml/>
GitHub <https://github.com/dida-do/eurocropsml>
Zenodo <https://zenodo.org/doi/10.5281/zenodo.10629609>
Contributing <https://github.com/dida-do/eurocropsml/blob/main/CONTRIBUTING.md>
```

[Full Index](genindex)